@@ -191,6 +191,8 @@ MainWindow::MainWindow(QWidget *parent)
 
     setDisplayOrientation(m_pAppSettings->value("QSpot/displayOrientation",ORIENTATION_DEFAULT).toInt()); //set initial display orientation for views / dialogs
 
+    m_pSession->setCachePath(m_pAppSettings->value("QSpot/cacheLocation", CACHE_PATH_EMMC + "/" + CACHE_DIR_NAME_DEFAULT).toString()); //set libspotify cache path
+    m_pSession->setSettingsPath(m_pAppSettings->value("QSpot/cacheLocation", CACHE_PATH_EMMC + "/" + CACHE_DIR_NAME_DEFAULT).toString()); //set libspotify settings path
     m_pSession->init(); //initialise new libspotify session prior to login
 
     QTimer::singleShot(1500,this,SLOT(OnHandleLoginType())); //proceed to login process (timer event delays process so that any initialisation has time to finish)
@@ -560,10 +562,6 @@ void MainWindow::OnPlayQueuePosUpdated(qint32 pos)
 
 void MainWindow::logout()
 {//logout the curent user and display the login dialog
-    //clear saved credentials
-    //m_pAppSettings->setValue("QSpot/SaveCredentials",0);
-   // m_pAppSettings->setValue("QSpot/UserID","");
-   // m_pAppSettings->setValue("QSpot/Password","");
     m_pSession->forgetCurrentUser();
     m_pSession->logout(); //logout current user
 }
@@ -633,7 +631,6 @@ void MainWindow::OnLoginResponse(Spotify::Error error)
               updatePlaylistModel(); //update playlists model
           }
       }
-
   }
 
 void MainWindow::OnPlaylistUpdated()
@@ -1005,7 +1002,7 @@ void MainWindow::OnHWZoomKeyPressed(quint32 keycode)
 void MainWindow::OnLoggedOut()
 {
     //logged out notification for current user
-    close(); //close down application on explicit logout request
+    close(); //close down application upon an explicit logout request.
 }
 
 void MainWindow::OnContextMenuRequested(QPoint pnt)
