@@ -1,6 +1,6 @@
 #ifndef ARTIST_H
 #define ARTIST_H
-#include <spotify/api.h>
+#include <libspotify/api.h>
 #include <QObject>
 #include <QString>
 
