@@ -1,6 +1,7 @@
 #ifndef ERROR_H
 #define ERROR_H
-#include <spotify/api.h>
+
+#include <libspotify/api.h>
 #include <QString>
 
 namespace Spotify
