@@ -8,9 +8,12 @@ Spotify::Session* Spotify::Session::callingSession;
 
 Spotify::Session::Session( QObject* parent ):
     QObject( parent ),
+    m_strCachePath( "" ),
+    m_strSettingsPath( "" ),
     m_currentTrack( 0 ),
     m_playlistcontainer( 0 ),
     m_currentUser( 0 ),
+    m_userReqLogout ( false ),
     m_offlineMode( false ),
     m_offlineModeForced ( false ),
     m_connRules ( (sp_connection_rules)(SP_CONNECTION_RULE_ALLOW_SYNC_OVER_WIFI| SP_CONNECTION_RULE_NETWORK_IF_ROAMING) ),
@@ -60,6 +63,16 @@ Spotify::Session::Session( QObject* parent ):
                     this, SLOT(OnOfflineStatusUpdated()),Qt::QueuedConnection);
 }
 
+void Spotify::Session::setCachePath(const QString& strCachePath)
+{//set the path for the libspotify cache data (directory will be created automatically if not exists upon session initialisation)
+    m_strCachePath = strCachePath;
+}
+
+void Spotify::Session::setSettingsPath(const QString& strSettingsPath)
+{//set the path for the libspotify settings data
+    m_strSettingsPath = strSettingsPath;
+}
+
 QString Spotify::Session::getRememberedUser()
 {
     //Returns remembered user (in case logged in via sp_session_relogin)
@@ -115,20 +128,23 @@ void Spotify::Session::init()
     //Init the current Spotify session.
     //Note: this method NEEDS to be initially called to set up the session.
 
+    QByteArray cachePath = m_strCachePath.toLatin1();
+    QByteArray settingsPath = m_strSettingsPath.toLatin1();
+
     // Set config parameters
     m_config.api_version = SPOTIFY_API_VERSION;
-    m_config.cache_location = "/home/user/MyDocs/.qspot";
-    m_config.settings_location = "/home/user/MyDocs/.qspot";
+    m_config.cache_location = cachePath.data();
+    m_config.settings_location = settingsPath.data();
     m_config.application_key = g_appkey;
     m_config.application_key_size = g_appkey_size;
     m_config.user_agent = "QSpot";
     m_config.callbacks = &g_callbacks;
 
-    // Initiate  / allocate session:
+    // Initiate  / allocate new session
     m_error = sp_session_create( &m_config, &m_session );
     if( m_error.isError() )
     {
-        qDebug() << "FATAL ERROR: Could not initiate session";
+        qDebug() << "FATAL ERROR: Could not initiate session. Error reason: " << m_error.toString();
     }
 
     m_pConnMan = new ConnectionManager(this); //allocate connection manager instance
@@ -137,9 +153,8 @@ void Spotify::Session::init()
     setNetworkState(); //sets connection type / rules
 
     m_ProcessEvents = false; //event processing not initiated
-
-   m_pProcEvtTimer = new QTimer(this);
-   connect(m_pProcEvtTimer,SIGNAL(timeout()),this,SLOT(OnProcessThreadEvents()));
+    m_pProcEvtTimer = new QTimer(this);
+    connect(m_pProcEvtTimer,SIGNAL(timeout()),this,SLOT(OnProcessThreadEvents()));
 }
 
 bool Spotify::Session::isOfflineMode()
@@ -337,7 +352,10 @@ void Spotify::Session::setConnectionRule(sp_connection_rules rule, bool state)
              if(m_currentTrack)
              {
                  if(!m_currentTrack->isOffline())
+                 {
                      stop(); //stop playback / buffering of current track in case it is not available offline
+                     qApp->removePostedEvents(this);
+                 }
              }
 
          }
@@ -415,6 +433,7 @@ void Spotify::Session::logout()
         delete m_currentUser;
         m_currentUser = NULL;
     }
+    m_userReqLogout = true; //indicate that user has request logout (signal will be emitted upon receiving loggedout callback)
     sp_session_logout( m_session );
 }
 
@@ -808,8 +827,6 @@ Spotify::Session::~Session()
     m_ProcessEvents = false;
     if(m_currentUser)
         m_currentUser->deleteLater();
-   // if(m_playlistcontainer)
-     //   sp_playlistcontainer_remove_callbacks(m_playlistcontainer,&pc_callbacks,NULL);
     if(m_pAudioThread)
     {//stop the audio playback thread in a controlled manner
         m_pAudioThread->stop();
@@ -1084,12 +1101,14 @@ void Spotify::Session::loggedInCallback( sp_session* session, sp_error error )
 void Spotify::Session::loggedInWrapper( Spotify::Error error )
 {
     // Let application know we're logged in (or not)
-    if(!m_currentUser)
-        m_currentUser = new Spotify::User( sp_session_user( m_session ) );
-   if(!m_playlistcontainer)
+   if(!m_playlistcontainer && !error.isError())
     {
+      if(!m_currentUser)
+          m_currentUser = new Spotify::User( sp_session_user( m_session ) );
+      qDebug() << "Registering container callbacks..";
       m_playlistcontainer = sp_session_playlistcontainer(m_session); //get root playlist container
       sp_playlistcontainer_add_callbacks(m_playlistcontainer,&pc_callbacks,NULL); //register callbacks
+      qDebug() << "Container callbacks registered..";
     }
 
    emit loggedIn( error );
@@ -1104,9 +1123,14 @@ void Spotify::Session::loggedOutCallback( sp_session* session )
 void Spotify::Session::loggedOutWrapper()
 {
     qDebug() << "Logged out";
-    emit loggedOut();
+    if(m_userReqLogout)
+    {
+        m_userReqLogout = false;
+        emit loggedOut();
+    }
 }
 
+
 void Spotify::Session::metadataUpdatedCallback( sp_session* session )
 {
     Q_UNUSED( session );
@@ -1127,6 +1151,7 @@ void Spotify::Session::connectionErrorCallback( sp_session* session, sp_error er
 void Spotify::Session::connectionErrorWrapper( Spotify::Error error )
 {
     Q_UNUSED( error );
+
     qDebug() << "Connection error: " << error.toString();
 }
 
