@@ -51,6 +51,10 @@ namespace Spotify
             // For mapping sp_playlist pointers to corresponding Spotify::Playlist pointers
             QHash< sp_playlist*, Spotify::Playlist* > m_playlistHash;
 
+            void setCachePath(const QString& strCachePath); //set the path for the libspotify cache data (directory will be created automatically if not exists upon session initialisation)
+
+            void setSettingsPath(const QString& strSettingsPath); //set the path for the libspotify settings data
+
             void init(); //initialise a new Spotify session
 
             void initAudio(); //init the audio / playback thread
@@ -492,9 +496,12 @@ namespace Spotify
             ConnectionManager* m_pConnMan; //connection mananger instance (get current online status etc.)
 
             sp_session_config m_config;
+            QString m_strCachePath; //libspotify cache path
+            QString m_strSettingsPath; //libspotify settings path
             sp_session* m_session; //current session instance
             sp_playlistcontainer* m_playlistcontainer;
             Spotify::User* m_currentUser;
+            bool m_userReqLogout; //set to true in case logout process has been initiated by user
             sp_connection_rules m_connRules; //currently set connection rules
             sp_connectionstate m_connState; //current session connection status
 
